@@ -128,7 +128,7 @@ class EmojiLayer(ImageLayer):
         super()._init()
         self.emoji = self.get_kwarg('emoji')
         if not is_emoji(self.emoji):
-            self.emoji = '🆘'
+            self.emoji = None
         super()._init_finished()
 
     def html_style(self):
@@ -160,6 +160,14 @@ class TextLayer(ColoredLayer):
     def _init(self):
         super()._init()
         self.font = self.get_kwarg('font', 'default')
+
+        self.background_color = self.get_kwarg('background_color', False)
+        if self.background_color and not isinstance(self.background_color, LinearGradientColor):
+            self.background_color = SingleColor(self.background_color)
+        self.background_padding = self.get_kwarg('background_padding', (0, 0))
+        self.border_radius = self.get_kwarg('border_radius', 0)
+
+        self.html_font = f"imagestack-{self.font}"
         self.font_size = self.get_kwarg('font_size', 16)
 
         self.line_margin = self.get_kwarg('line_margin', 0)
@@ -225,7 +233,7 @@ class TextLayer(ColoredLayer):
             .format(
                 self.html_position_style(self.max_size),
                 size_to_html(self.max_size, self),
-                self.font,
+                self.html_font,
                 self.font_size
             )
         return style
