@@ -22,7 +22,7 @@ class VisitorHtml:
             with open(font_path, "rb") as font_file:
                 base64_font = base64.b64encode(font_file.read()).decode('ascii')
             style_html.append('@font-face {{'
-                              'font-family:\'{}\';'
+                              'font-family:\'imagestack-{}\';'
                               'src:url(data:application/x-font-woff;charset=utf-8;base64,{}) format(\'woff\');'
                               '}}'
                               .format(key, base64_font))
@@ -114,6 +114,9 @@ class VisitorHtml:
             .format(el.html_style(), el.html_image(el.url))
 
     def visit_EmojiLayer(self, el):
+        emoji = el.emoji
+        if emoji is None:
+            emoji = self.image_creator.emoji_fallback
         self.check_set_max_size(el.pos, el.resize, el)
         return '<div data-layer="EmojiLayer" style="{}">{}</div>' \
             .format(el.html_style(), el.emoji)
@@ -129,8 +132,14 @@ class VisitorHtml:
             inner_style += 'align-items:center;'
         elif el.align_y == 'bottom':
             inner_style += 'align-items:flex-end;'
+        background_div = '{}'
+        if el.background_color:
+            background_div = '<div style="width:fit-content;height:fit-content;' \
+                             'border-radius:{}px;padding:{}px {}px;{}">{{}}</div>'.format(
+                el.border_radius, el.background_padding[1], el.background_padding[0],
+                el.background_color.html_style_background())
         return '<div data-layer="TextLayer" style="{}"><div style="{}">{}</div></div>' \
-            .format(el.html_style(), inner_style, el.lines_html())
+            .format(el.html_style(), inner_style, background_div.format(el.lines_html()))
 
     def visit_RectangleLayer(self, el):
         self.check_set_max_size(el.pos, el.size, el)
